abacusai.inferred_database_column_to_feature_mappings — AbacusAI documentation

# abacusai.inferred_database_column_to_feature_mappings

## Classes

`DatabaseColumnFeatureMapping` | Mapping for export of feature group version to database column
`AbstractApiClass` |
`InferredDatabaseColumnToFeatureMappings` | Autocomplete mappings for database to connector columns

## Module Contents

class abacusai.inferred_database_column_to_feature_mappings.DatabaseColumnFeatureMapping(client, databaseColumn=None, feature=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Mapping for export of feature group version to database column

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - databaseColumn (str) – database column name

    - feature (str) – feature group column it has been matched to

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.inferred_database_column_to_feature_mappings.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.inferred_database_column_to_feature_mappings.InferredDatabaseColumnToFeatureMappings(client, databaseColumnToFeatureMappings={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Autocomplete mappings for database to connector columns

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - databaseColumnToFeatureMappings (DatabaseColumnFeatureMapping) – Database columns feature mappings

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict